@@ -50,6 +50,8 @@ class Overlay(Thread):
 				self.period = 1.0/frequency
 		else:
 			self.period = 0
+		self.x_min = 0
+		self.y_min = 0
 		self.daemon = True
 		self.start()
 
@@ -60,6 +62,11 @@ class Overlay(Thread):
 			:param h_wnd: an input argument
 			:returns: nothing
 			"""
+			if message == win32con.WM_QUIT:
+				# print("Closing the window overlay")
+				win32gui.PostQuitMessage(0)
+				return 0
+			
 			if message == win32con.WM_PAINT:
 				hdc, paint_struct = win32gui.BeginPaint(h_wnd)
 				win32gui.SetGraphicsMode(hdc, win32con.GM_ADVANCED)
@@ -72,11 +79,11 @@ class Overlay(Thread):
 					else:
 						geometry = None
 					if 'x' in r:
-						x = r['x']
+						x = r['x'] - self.x_min
 					else:
 						x = 0
 					if 'y' in r:
-						y = r['y']
+						y = r['y'] - self.y_min
 					else:
 						y = 0
 					if 'width' in r:
@@ -113,7 +120,8 @@ class Overlay(Thread):
 					if 'geometry' in r and r['geometry'] is Shape.triangle:
 						vertices = ()
 						for xyrgb in xyrgb_array:
-							vertices = vertices + ({'x': int(round(xyrgb[0])) , 'y': int(round(xyrgb[1])),
+							vertices = vertices + ({'x': int(round(xyrgb[0])) - self.x_min,
+							                        'y': int(round(xyrgb[1])) - self.y_min,
 													'Red': xyrgb[2] * 256,
 													'Green': xyrgb[3] * 256,
 													'Blue': xyrgb[4] * 256,
@@ -183,7 +191,12 @@ class Overlay(Thread):
 													'M21': math.sin(r_angle) * -1, 'M22': math.cos(r_angle),
 													'Dx': x, 'Dy': y})
 						x, y = -center_of_rotation_x, -center_of_rotation_y
-
+					
+					if 'text_format' in r:
+						text_format = eval(r['text_format'])
+					else:
+						text_format = win32con.DT_CENTER | win32con.DT_SINGLELINE | win32con.DT_VCENTER
+						
 					if 'geometry' in r:
 						if r['geometry'] is Shape.rectangle:
 							win32gui.Rectangle(
@@ -201,7 +214,7 @@ class Overlay(Thread):
 						elif r['geometry'] is Shape.triangle and thickness > 0:
 							t = ()
 							for xyrgb in xyrgb_array:
-								t = t + ((int(round(xyrgb[0])), int(round(xyrgb[1]))),)
+								t = t + ((int(round(xyrgb[0])), + int(round(xyrgb[1]))),)
 							t = t + ((int(round(xyrgb_array[0][0])), int(round(xyrgb_array[0][1]))),)
 							win32gui.Polyline(hdc, t)
 						if angle != 0:
@@ -241,11 +254,8 @@ class Overlay(Thread):
 							text_bg_color_b = brush_color_b
 						win32gui.SetBkMode(hdc, win32con.TRANSPARENT)
 						win32gui.SetBkColor(hdc, win32api.RGB(text_bg_color_r, text_bg_color_g, text_bg_color_b))
-						text_format = win32con.DT_CENTER | win32con.DT_SINGLELINE | win32con.DT_VCENTER
 						tuple_r = tuple([int(round(x)), int(round(y)), int(round(x + width)), int(round(y + height))])
-						win32gui.DrawTextW(hdc, text, -1, tuple_r, text_format | win32con.DT_CALCRECT)
 						win32gui.DrawTextW(hdc, text, -1, tuple_r, text_format)
-
 						win32gui.SelectObject(hdc, old_font)
 				win32gui.EndPaint(h_wnd, paint_struct)
 				return 0
@@ -270,16 +280,18 @@ class Overlay(Thread):
 			ex_style, wnd_class_atom,
 			'OverlayWindow',
 			style,
-			0,  # x
-			0,  # y
-			win32api.GetSystemMetrics(win32con.SM_CXSCREEN),  # width
-			win32api.GetSystemMetrics(win32con.SM_CYSCREEN),  # height
+			win32api.GetSystemMetrics(win32con.SM_XVIRTUALSCREEN),  # x
+			win32api.GetSystemMetrics(win32con.SM_YVIRTUALSCREEN),  # y
+			win32api.GetSystemMetrics(win32con.SM_CXVIRTUALSCREEN),  # width
+			win32api.GetSystemMetrics(win32con.SM_CYVIRTUALSCREEN),  # height
 			None,  # hWndParent
 			None,  # hMenu
 			h_instance,
 			None  # lpParam
 		)
-
+		monitors = win32api.EnumDisplayMonitors()
+		self.x_min = min([win32api.GetMonitorInfo(monitor[0])['Work'][0] for monitor in monitors])
+		self.y_min = min([win32api.GetMonitorInfo(monitor[0])['Work'][1] for monitor in monitors])
 		win32gui.SetLayeredWindowAttributes(self.h_window, 0x00ffffff, self.transparency,
 											win32con.LWA_COLORKEY | win32con.LWA_ALPHA)
 		win32gui.SetWindowPos(self.h_window, win32con.HWND_TOPMOST, 0, 0, 0, 0,
@@ -287,7 +299,9 @@ class Overlay(Thread):
 
 		if self.period > 0:
 			self.auto_refresh()
+		#print("PumpMessages start")
 		win32gui.PumpMessages()
+		#print("Overlay quit")
 
 	def refresh(self):
 		win32gui.InvalidateRect(self.h_window, None, True)
@@ -301,6 +315,10 @@ class Overlay(Thread):
 
 	def clear_all(self):
 		del self.graphical_elements[:]
+		
+	def quit(self):
+		win32gui.SendMessage(self.h_window, win32con.WM_QUIT, 0, 0)
+		self.join()
 
 
 def load_png(filename, size_x, size_y):
@@ -310,13 +328,17 @@ def load_png(filename, size_x, size_y):
 	return CreateIconFromResourceEx(png, len(png), 1, 0x30000, size_x, size_y, LR_DEFAULTCOLOR)
 
 
+def load_ico(filename, size_x, size_y):
+	return win32gui.LoadImage(0, filename, win32con.IMAGE_ICON, size_x, size_y, win32con.LR_LOADFROMFILE)
+
+
 if __name__ == '__main__':
 	import time
 
 	main_overlay = Overlay()
 	transparent_overlay = Overlay(transparency=0.5)
 
-	transparent_overlay.add(geometry=Shape.rectangle, x=300, y=300, width=100, height=100, thickness=10,
+	transparent_overlay.add(geometry=Shape.rectangle, x=300, y=800, width=100, height=1000, thickness=10,
 							color=(0, 255, 0))
 	transparent_overlay.refresh()
 
@@ -335,8 +357,12 @@ if __name__ == '__main__':
 					 xyrgb_array=((815, 150, 255, 0, 0), (1400, 150, 0, 255, 0), (1400, 800, 0, 0, 255)),
 					 )
 
-	main_overlay.add(geometry=Shape.rectangle, x=1200, y=300, width=400, height=100, thickness=10, color=(0, 0, 255),
-					 text_color=(255, 255, 254), text=u'Pywinauto recorder 0.1.0', font_size=40)
+	main_overlay.add(geometry=Shape.rectangle, x=1200, y=300, width=400, height=0, thickness=10, color=(0, 0, 255),
+					 text_color=(255, 255, 254),
+					 text=u'Pywinauto recorder 0.1.0 blabla blabla blabla blabla blabla blabla xxx xxx xxx xxx xxx xxx xxx xxx xxx xxx xxx xxx xxx\n aaaaaaaa aaaaaaaa aaaaaaaa aaaaaaaa aaaaaaaa\n aaaaaaaa aaaaaaaa aaaaaaaa aaaaaaaa aaaaaaaa\n aaaaaaaa aaaaaaaa aaaaaaaa aaaaaaaa aaaaaaaa',
+					 # text_format="win32con.DT_CENTER | win32con.DT_NOCLIP | win32con.DT_VCENTER",
+					 text_format="win32con.DT_LEFT | win32con.DT_TOP | win32con.DT_WORDBREAK | win32con.DT_WORD_ELLIPSIS | win32con.DT_NOCLIP",
+					 font_size=40)
 
 
 
@@ -358,19 +384,27 @@ if __name__ == '__main__':
 
 	main_overlay.add(geometry=Shape.ellipse, x=10, y=800, width=40, height=40,
 					 color=(255, 0, 0), thickness=2, brush=Brush.solid, brush_color=(255, 255, 254))
+	
 
-
+	
 	main_overlay.refresh()
-	hicon = load_png(r'C:\Users\d_pra\PycharmProjects\pywinauto_recorder\Images\Download.png', 40, 40)
+	time.sleep(2)
+	transparent_overlay.quit()
+	main_overlay.quit()
+
+	
+	hicon = load_ico(r'C:\Users\oktalse\PycharmProjects\pywinauto_recorder\pywinauto_recorder\Icons\play.ico', 48, 48)
 
 
 	time.sleep(1)
 	animated_overlay = Overlay(transparency=0.5, frequency=25.)
 	animated_overlay.refresh()
+	
 
+	
 	x, y = 350, 600
 	a = 0.0
-	for i in range(1000):
+	for i in range(100):
 		animated_overlay.clear_all()
 		animated_overlay.add(geometry=Shape.image, hicon=hicon, x=120, y=700)
 		animated_overlay.add(geometry=Shape.image, hicon=hicon, x=x, y=y, angle=a, center_of_rotation=(20, 20))
@@ -380,4 +414,5 @@ if __name__ == '__main__':
 		time.sleep(1./25.)
 
 
-	#time.sleep(99.0)
+	
+	animated_overlay.quit()
